package com.fs.hisStore.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.hisStore.domain.FsStoreCouponIssueScrm;
import com.fs.hisStore.param.FsCouponIssueParam;
import com.fs.hisStore.param.FsStoreCouponReceiveParam;
import com.fs.hisStore.vo.FsStoreCouponIssueVO;

/**
 * 优惠券领取Service接口
 * 
 * @author fs
 * @date 2022-03-15
 */
public interface IFsStoreCouponIssueScrmService 
{
    /**
     * 查询优惠券领取
     * 
     * @param id 优惠券领取ID
     * @return 优惠券领取
     */
    public FsStoreCouponIssueScrm selectFsStoreCouponIssueById(Long id);

    /**
     * 查询优惠券领取列表
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 优惠券领取集合
     */
    public List<FsStoreCouponIssueScrm> selectFsStoreCouponIssueList(FsStoreCouponIssueScrm fsStoreCouponIssue);

    /**
     * 新增优惠券领取
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 结果
     */
    public int insertFsStoreCouponIssue(FsStoreCouponIssueScrm fsStoreCouponIssue);

    /**
     * 修改优惠券领取
     * 
     * @param fsStoreCouponIssue 优惠券领取
     * @return 结果
     */
    public int updateFsStoreCouponIssue(FsStoreCouponIssueScrm fsStoreCouponIssue);

    /**
     * 批量删除优惠券领取
     * 
     * @param ids 需要删除的优惠券领取ID
     * @return 结果
     */
    public int deleteFsStoreCouponIssueByIds(Long[] ids);

    /**
     * 删除优惠券领取信息
     * 
     * @param id 优惠券领取ID
     * @return 结果
     */
    public int deleteFsStoreCouponIssueById(Long id);

    List<FsStoreCouponIssueVO> selectFsStoreCouponIssueListQueryVO(String userId, FsStoreCouponIssueScrm map);

    R receive(String userId, FsStoreCouponReceiveParam param);

    List<FsStoreCouponIssueVO> getCompanyCouponIssueList(FsCouponIssueParam map);

    FsStoreCouponIssueVO selectFsStoreCouponIssueVOById(Long id);

    List<FsStoreCouponIssueVO> selectFsStoreCouponIssueListVO(FsStoreCouponIssueScrm fsStoreCouponIssue);
}
