package com.fs.hisStore.controller;

import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.core.page.TableDataInfo;
import com.fs.common.enums.BusinessType;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.hisStore.domain.FsStoreCouponIssueScrm;
import com.fs.hisStore.service.IFsStoreCouponIssueScrmService;
import com.fs.hisStore.vo.FsStoreCouponIssueVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 优惠券领取Controller
 *
 * @author fs
 * @date 2022-03-15
 */
@RestController
@RequestMapping("/store/storeCouponIssue")
public class FsStoreCouponIssueScrmController extends BaseController
{
    @Autowired
    private IFsStoreCouponIssueScrmService fsStoreCouponIssueService;

    /**
     * 查询优惠券领取列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreCouponIssueScrm fsStoreCouponIssue)
    {
        startPage();
        List<FsStoreCouponIssueVO> list = fsStoreCouponIssueService.selectFsStoreCouponIssueListVO(fsStoreCouponIssue);
        return getDataTable(list);
    }

    /**
     * 导出优惠券领取列表
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:export')")
    @Log(title = "优惠券领取", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreCouponIssueScrm fsStoreCouponIssue)
    {
        List<FsStoreCouponIssueScrm> list = fsStoreCouponIssueService.selectFsStoreCouponIssueList(fsStoreCouponIssue);
        ExcelUtil<FsStoreCouponIssueScrm> util = new ExcelUtil<FsStoreCouponIssueScrm>(FsStoreCouponIssueScrm.class);
        return util.exportExcel(list, "storeCouponIssue");
    }

    /**
     * 获取优惠券领取详细信息
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(fsStoreCouponIssueService.selectFsStoreCouponIssueById(id));
    }

    /**
     * 新增优惠券领取
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:add')")
    @Log(title = "优惠券领取", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreCouponIssueScrm fsStoreCouponIssue)
    {
        return toAjax(fsStoreCouponIssueService.insertFsStoreCouponIssue(fsStoreCouponIssue));
    }

    /**
     * 修改优惠券领取
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:edit')")
    @Log(title = "优惠券领取", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreCouponIssueScrm fsStoreCouponIssue)
    {
        return toAjax(fsStoreCouponIssueService.updateFsStoreCouponIssue(fsStoreCouponIssue));
    }

    /**
     * 删除优惠券领取
     */
    @PreAuthorize("@ss.hasPermi('store:storeCouponIssue:remove')")
    @Log(title = "优惠券领取", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fsStoreCouponIssueService.deleteFsStoreCouponIssueByIds(ids));
    }
}
